@@ -1,6 +1,5 @@
 import pandas as pd
-import clickhouse_driver
-
+import requests
 from mindsdb_datasources.datasources.data_source import SQLDataSource
 
 
@@ -12,6 +11,7 @@ class ClickhouseDS(SQLDataSource):
                  host='localhost',
                  user='default',
                  password='',
+                 protocol='http',
                  port=9000):
 
         if ' format ' in query.lower():
@@ -25,14 +25,26 @@ class ClickhouseDS(SQLDataSource):
         self.port = int(port)
         self.user = user
         self.password = password
+        self.protocol = protocol
 
     def query(self, q):
-        with clickhouse_driver.connect(host=self.host,
-                                       port=self.port,
-                                       database=self.database,
-                                       user=self.user,
-                                       password=self.password) as con:
-            df = pd.read_sql(q, con=con)
+        q = '{} FORMAT JSON'.format(q.rstrip(" ;\n"))
+        params = {'user': self.user}
+        if self.password is not None:
+            params['password'] = self.password
+    
+        response = requests.post(
+            f'{self.protocol}://{self.host}:{self.port}',
+            data=q,
+            params=params
+        )
+
+        try:
+            data = response.json()['data']
+        except Exception:
+            raise Exception(f'Got an invalid response from the database: {response.text}')
+
+        df = pd.DataFrame(data)
 
         return df, self._make_colmap(df)
 
